]> sigrok.org Git - libsigrok.git/commitdiff
std.c: Changed return value of std_dev_acquisition_stop_serial() for non-active devic...
authorMatthias Heidbrink <redacted>
Thu, 17 Oct 2013 08:57:16 +0000 (10:57 +0200)
committerUwe Hermann <redacted>
Fri, 25 Oct 2013 19:25:26 +0000 (21:25 +0200)
std.c

diff --git a/std.c b/std.c
index 46ab5ad95dc30c343dd0fe858b3552cbd919127f..22123fc5d743dc527ca31af3e3cdca549cf8b31d 100644 (file)
--- a/std.c
+++ b/std.c
@@ -117,8 +117,10 @@ SR_PRIV int std_session_send_df_header(const struct sr_dev_inst *sdi,
  * @param prefix A driver-specific prefix string used for log messages.
  *               Must not be NULL. An empty string is allowed.
  *
* @return SR_OK upon success, SR_ERR_ARG upon invalid arguments, or
*         SR_ERR upon other errors.
  */
 SR_PRIV int std_dev_acquisition_stop_serial(struct sr_dev_inst *sdi,
                        void *cb_data, dev_close_t dev_close_fn,
@@ -134,7 +136,7 @@ SR_PRIV int std_dev_acquisition_stop_serial(struct sr_dev_inst *sdi,
 
        if (sdi->status != SR_ST_ACTIVE) {
                sr_err("%sDevice inactive, can't stop acquisition.", prefix);
-               return SR_ERR;
+               return SR_ERR_DEV_CLOSED;
        }
 
        sr_dbg("%sStopping acquisition.", prefix);
@@ -117,8 +117,10 @@ SR_PRIV int std_session_send_df_header(const struct sr_dev_inst *sdi,
  *               Must not be NULL. An empty string is allowed.
  *
- * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments, or
- *         SR_ERR upon other errors.
+ * @retval SR_OK Success.
+ * @retval SR_ERR_ARG Invalid arguments.
+ * @retval SR_ERR_DEV_CLOSED Device is closed.
+ * @retval SR_ERR Other errors.
  */
 SR_PRIV int std_dev_acquisition_stop_serial(struct sr_dev_inst *sdi,